Community Developed Modules
============================

Documentation for community developed lightcurve and activity classes.

Lightcurve Classes Documentation
--------------------------------

.. NOTE: Please add new pages alphabetically
.. toctree::
    Sinusoidal Lightcurve <community_modules/lightcurve/sinusoidal>


Activity Classes Documentation
------------------------------

.. NOTE: Please add new pages alphabetically
.. toctree::
    LSST Comet <community_modules/activity/lsst_comet>
